@@ -53,7 +53,8 @@ decorate.elm = function(x, data, ...){
 #' iris_y = iris[, ncol(iris)]
 #' iris.glmnet = glmnet(x = iris_X, y = iris_y, family = "multinomial")
 #' iris.glmnet = decorate(iris.glmnet, lambda.s = iris.glmnet$lambda[49])
-#' r2pmml(iris.glmnet, file.path(tempdir(), "Iris-GLMNet.pmml"))
+#' # Please uncomment the next line
+#' #r2pmml(iris.glmnet, file.path(tempdir(), "Iris-GLMNet.pmml"))
 #' }
 decorate.glmnet = function(x, lambda.s, ...){
 
@@ -78,7 +79,8 @@ decorate.glmnet = function(x, lambda.s, ...){
 #' iris.party = evtree(Species ~ ., data = iris,
 #'     control = evtree.control(max_depth = 3))
 #' iris.party = decorate(iris.party)
-#' r2pmml(iris.party, file.path(tempdir(), "Iris-Party.pmml"))
+#' # Please uncomment the next line
+#' #r2pmml(iris.party, file.path(tempdir(), "Iris-Party.pmml"))
 #' }
 decorate.party = function(x, ...){
 
@@ -122,7 +124,8 @@ decorate.randomForest = function(x, compact = FALSE, ...){
 #' iris.ranger = ranger(Species ~ ., data = iris, num.trees = 17,
 #'     write.forest = TRUE, probability = TRUE)
 #' iris.ranger = decorate(iris.ranger, data = iris)
-#' r2pmml(iris.ranger, file.path(tempdir(), "Iris-Ranger.pmml"))
+#' # Please uncomment the next line
+#' #r2pmml(iris.ranger, file.path(tempdir(), "Iris-Ranger.pmml"))
 #' }
 decorate.ranger = function(x, data, ...){
 
@@ -194,22 +197,38 @@ decorate.WrappedModel = function(x, invert_levels = FALSE, ...){
 #' data(iris)
 #' iris_X = iris[, -ncol(iris)]
 #' iris_y = iris[, ncol(iris)]
-#' # Convert from factor to integer[0, num_class]
-#' iris_y = (as.integer(iris_y) - 1)
-#' iris.matrix = model.matrix(~ . - 1, data = iris_X)
-#' iris.DMatrix = xgb.DMatrix(iris.matrix, label = iris_y)
-#' iris.fmap = as.fmap(iris.matrix)
-#' iris.xgboost = xgboost(data = iris.DMatrix,
-#'     objective = "multi:softprob", num_class = 3, nrounds = 11)
-#' iris.xgboost = decorate(iris.xgboost, iris.fmap, 
-#'     response_name = "Species", response_levels = c("setosa", "versicolor", "virginica"))
+#' iris.fmap = as.fmap(iris_X)
+#' iris.xgboost = xgboost(
+#'   x = iris_X, y = iris_y,
+#'   objective = "multi:softprob",
+#'   nrounds = 11
+#' )
+#' # Please uncomment the next two lines
+#' #iris.xgboost = decorate(iris.xgboost, iris.fmap, 
+#' #    response_name = "Species", response_levels = c("setosa", "versicolor", "virginica"))
 #' pmmlFile = file.path(tempdir(), "Iris-XGBoost.pmml")
-#' r2pmml(iris.xgboost, pmmlFile, compact = FALSE)
+#' # Please uncomment the next line
+#' #r2pmml(iris.xgboost, pmmlFile, compact = FALSE)
 #' compactPmmlFile = file.path(tempdir(), "Iris-XGBoost-compact.pmml")
-#' r2pmml(iris.xgboost, compactPmmlFile, compact = TRUE)
+#' # Please uncomment the next line
+#' #r2pmml(iris.xgboost, compactPmmlFile, compact = TRUE)
 #' }
 decorate.xgb.Booster = function(x, fmap, response_name = NULL, response_levels = c(), missing = NULL, ntreelimit = NULL, compact = FALSE, ...){
 
+	# Transform XGBoost 3.X object to XGBoost 1.X/2.X-style object
+	if(is.list(x) && "ptr" %in% names(x) && typeof(x$ptr) == "externalptr"){
+		raw_bytes = xgboost::xgb.save.raw(x)
+
+		verification = attr(x, "verification")
+
+		x = list(raw = raw_bytes)
+		class(x) = "xgb3.Booster"
+
+		if(!is.null(verification)){
+			x$verification = verification
+		}
+	}
+
 	if(is.null(x$fmap)){
 		x$fmap = fmap
 	}
