@@ -24,6 +24,7 @@ import java.util.Collections;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
@@ -70,6 +71,8 @@ public class GBDT {
 
 	private Map<String, String> feature_importances = Collections.emptyMap();
 
+	private String linear_tree;
+
 	private List<List<?>> pandas_categorical = Collections.emptyList();
 
 
@@ -150,6 +153,8 @@ public class GBDT {
 				break parameters;
 			}
 
+			this.linear_tree = section.get("linear_tree", false);
+
 			index++;
 
 			index = skipEndSection("end of parameters", sections, index);
@@ -520,6 +525,10 @@ public class GBDT {
 		this.object_function_ = object_function_;
 	}
 
+	public boolean hasLinearTree(){
+		return Objects.equals("1", this.linear_tree);
+	}
+
 	private Boolean isBinary(int feature){
 		String featureInfo = this.feature_infos_[feature];
 
