@@ -18,6 +18,8 @@
  */
 package org.jpmml.rexp;
 
+import java.io.IOException;
+import java.util.Collections;
 import java.util.List;
 
 import com.google.common.primitives.Doubles;
@@ -28,12 +30,49 @@ public class RDoubleVector extends RNumberVector<Double> {
 	private double[] values = null;
 
 
+	public RDoubleVector(Number value, RPair attributes){
+		this(Collections.singletonList(value), attributes);
+	}
+
+	public RDoubleVector(List<Number> values, RPair attributes){
+		super(attributes);
+
+		this.values = values.stream()
+			.mapToDouble(value -> {
+
+				if(value == null){
+					return Double.NaN;
+				}
+
+				return value.doubleValue();
+			})
+			.toArray();
+	}
+
 	public RDoubleVector(double[] values, RPair attributes){
 		super(attributes);
 
 		this.values = values;
 	}
 
+	@Override
+	int type(){
+		return SExpTypes.REALSXP;
+	}
+
+	@Override
+	void writeValues(RDataOutput output) throws IOException {
+		double[] values = this.values;
+
+		int length = values.length;
+
+		output.writeInt(length);
+
+		for(int i = 0; i < length; i++){
+			output.writeDouble(values[i]);
+		}
+	}
+
 	@Override
 	public DataType getDataType(){
 		return DataType.DOUBLE;
