@@ -82,6 +82,12 @@ public class FeatureMap {
 		return result;
 	}
 
+	public boolean isEmpty(){
+		List<Entry> entries = getEntries();
+
+		return entries.isEmpty();
+	}
+
 	public void update(FeatureMap featureMap){
 		List<Entry> entries = getEntries();
 
@@ -89,7 +95,7 @@ public class FeatureMap {
 			List<Entry> updateEntries = featureMap.getEntries(entry.getName());
 
 			if(updateEntries.isEmpty()){
-				throw new IllegalArgumentException();
+				throw new IllegalArgumentException("Feature \'" + entry.getName() + "\' has no feature map entries");
 			} // End if
 
 			if(entry instanceof CategoricalEntry){
@@ -365,10 +371,19 @@ public class FeatureMap {
 
 				BitSet splitIndices = gbtree.getSplitCategories(index);
 
-				// Binary categorical features
-				int size = Math.max(splitIndices.length(), 2);
+				// Used feature
+				if(splitIndices != null){
+					// Binary categorical features only exhibit one "effective" category level
+					int size = Math.max(splitIndices.length(), 2);
 
-				values = new IntegerRange(size);
+					values = new IntegerRange(size);
+				} else
+
+				// Unused feature
+				{
+					// Constant-like feature
+					values = new IntegerRange(1);
+				}
 
 				dataType = DataType.INTEGER;
 			}
