@@ -19,7 +19,7 @@
 package org.jpmml.xgboost;
 
 abstract
-public class GradientBooster implements BinaryLoadable, JSONLoadable {
+public class GradientBooster implements BinaryLoadable, JSONLoadable, UBJSONLoadable {
 
 	abstract
 	public String getAlgorithmName();
